==> persian_date-0.0.4.tar.gz: README.md <==
تاریخ شمسی برای دارت و فلاتر

- [جهت استفاده از مبدل همراه با تقویم و Date Picker از این پکیج استفاده نماید](https://pub.dartlang.org/packages/jalali_calendar)



تبدیل تاریخ میلادی به شمسی به وسیله این کتابخانه قادر هستید که تاریخ های میلادی را به شمسی و بلعکس تبدیل کنید
در بروز رسانی های بعدی مواردی بیشتری به کتاب خانه اضافه خواهند شد 
## استفاده از کتاب خانه 

چند مثال ساده

افزودن پارس تاریخ مشخص و دریافت اطلاعات ان بجای تاریخ فعلی

```dart
import 'package:PersianDate/PersianDate.dart';

main() {
  
  PersianDate persianDate = PersianDate("yyyy/mm/dd  \n DD  , d  MM  ");
  
  persianDate.getNow;
  
// یا
  
  PersianDate persianDate = PersianDate();
  
  persianDate.getNow ;// تاریخ فعلی
  
    // فرمت gregorian باید طبق "yyyy-mm-dd"باشد اگر نمیخواهید تاریخ مشخص پارس شود چیزی وارد نکنید. 

  PersianDate date = PersianDate.pDate(gregorian: "1989-08-18"); // برگشت تاریخ مشخص
  
  date.getDate // در صورتی که از سازنده  pdate همراه با تاریخ میلادی مشخص استفاده میکنید با این تابع شمسی همان تاریخ برگشت داده میشود
  
  
    print("year ${date.year}");
    print("isHoliday ${date.isHoliday}");
    print("isHoliday ${date.weekdayname}");
    print(date.monthname); // نام ماه
      print(date.month); // ماه
      print(date.day); // روز
      print(date.hour);// ساعت
      print(date.minute);// دقیقه
      print(date.second);// ثانیه
      print(date.millisecond); // میلی ثانیه
      print(date.microsecond);//
     
 
 // برگرداندن یک تاریخ خاص از سال میلادی
    var Gdate = new DateTime(1989,08,21);
    print("${date.parse(Gdate.toString(),"/")}"); // اگر جدا کننده قرار داده نشود به صورت یک لیست بر میگرداند
    print("${date.parse(Gdate.toString())}"); // 
  
  // با فرمت دلخواه
  print("${date.parseToFormat(Gdate.toString())}");
  print("${date.parseToFormat(Gdate.toString(),"yyyy-m-dd h:n:ss")}");
  
     // تبدیل تاریخ شمسی به میلادی اگر جدا کننده نداشته باشه به صورت یک لیست بر میگرداند
print(date.jalaliToGregorian(1397, 09, 12));

  // مواردی که میتوانید با فراخوانی دریافت کنید.
  print(date.isHoliday); // روز تعطیل است یا خیر
  print(date.weekdayname); // نام روز
  print(date.monthname); // نام ماه
    print(date.year); // سال 
    print(date.month); // ماه
    print(date.day); // روز
    print(date.hour);// ساعت
    print(date.minute);// دقیقه
    print(date.second);// ثانیه
    print(date.millisecond); // میلی ثانیه
    print(date.microsecond);// میکرو ثانیه
    
  
  }
```

کلید فرمت های که میتوانید استفاده کنید

yyyy // 4 عدد سال

yy // 2 عدد سال

mm // 2 عدد ماه اگر ماه تک رقمی باشد 0 در اول ان قرار میدهد

m // 1 عدد ماه اگر ماه تک رقمی باشد 0 قرار نمیدهد

MM // ماه به صورت حروفی کامل

M // ماه به صورت حروفی کوتاه

dd // روز به صورت 2 عددی

d // روز به صورت تک رقمی برای روز های زیر 10

w // عدد هفته از ماه را بر میگرداند

DD // نام روز

D // نام روز

hh // ساعت با دو رقم اگر ساعت تک رقمی باشد 0 ابتدای عدد قرار میدهد فرمت 12 ساعته

h // ساعت با تک رقم فرمت 12 ساعته 

HH // ساعت با 2 رقم فرمت 24 ساعته 

H // ساعت با تک رقم فرمت 24 ساعته

nn // نمایشه دقیقه به صورت دو رقمی

n // نمایشه دقیقه به صورت تک رقمی

ss // نمایش ثانیه دو رقمی

s  // نمایش ثانیه تک رقمی

SSS // نمایش میلی ثانیه

S // نمایش میلی ثانیه

uuu // نمایش میکرو ثانیه

u // نمایش میکرو ثانیه

am // نمایش وقت به صورت کوتاه 

AM // نمایش وقت به صورت کامل


## گزارش اشکال

در صورت وجود هر گونه مشکل از طریق ایمیل زیر با ما در میان بگذارید[j.zobeidi89@gmail.com][tracker].

[tracker]: mailto:j.zobeidi89@gmail.com

==> persian_date-0.1.1.tar.gz: README.md <==
تاریخ شمسی برای دارت و فلاتر

- [جهت استفاده از مبدل همراه با تقویم و Date Picker از این پکیج استفاده نماید](https://pub.dartlang.org/packages/jalali_calendar)



تبدیل تاریخ میلادی به شمسی به وسیله این کتابخانه قادر هستید که تاریخ های میلادی را به شمسی و بلعکس تبدیل کنید
در بروز رسانی های بعدی مواردی بیشتری به کتاب خانه اضافه خواهند شد 
## استفاده از کتاب خانه 

چند مثال ساده

افزودن پارس تاریخ مشخص و دریافت اطلاعات ان بجای تاریخ فعلی

```dart
import 'package:PersianDate/PersianDate.dart';

main() {
  
  PersianDate persianDate = PersianDate(gregorian: "1989-01-29");
    print("Now ${persianDate.getDate}");
    print("Now ${persianDate.Now}");
    print(persianDate.hour);
    print("year ${persianDate.year}");
    print("isHoliday ${persianDate.isHoliday}");
    print("isHoliday ${persianDate.weekdayname}");
    print(persianDate.monthname); // نام ماه
      print(persianDate.month); // ماه
      print(persianDate.day); // روز
      print(persianDate.hour);// ساعت
      print(persianDate.minute);// دقیقه
      print(persianDate.second);// ثانیه
      print(persianDate.millisecond); // میلی ثانیه
      print(persianDate.microsecond);//
     
 
 // برگرداندن یک تاریخ خاص از سال میلادی
    var Gdate = new DateTime(1989,08,21);
    print("${persianDate.parse(Gdate.toString(),"/")}"); // اگر جدا کننده قرار داده نشود به صورت یک لیست بر میگرداند
    print("${persianDate.parse(Gdate.toString())}"); // 
  
  // با فرمت دلخواه
  print("${persianDate.parseToFormat(Gdate.toString())}");
  print("${persianDate.parseToFormat(Gdate.toString(),"yyyy-m-dd h:n:ss")}");
  
     // تبدیل تاریخ شمسی به میلادی اگر جدا کننده نداشته باشه به صورت یک لیست بر میگرداند
print(persianDate.jalaliToGregorian(1397, 09, 12));

    
  }
```

کلید فرمت های که میتوانید استفاده کنید

yyyy // 4 عدد سال

yy // 2 عدد سال

mm // 2 عدد ماه اگر ماه تک رقمی باشد 0 در اول ان قرار میدهد

m // 1 عدد ماه اگر ماه تک رقمی باشد 0 قرار نمیدهد

MM // ماه به صورت حروفی کامل

M // ماه به صورت حروفی کوتاه

dd // روز به صورت 2 عددی

d // روز به صورت تک رقمی برای روز های زیر 10

w // عدد هفته از ماه را بر میگرداند

DD // نام روز

D // نام روز

hh // ساعت با دو رقم اگر ساعت تک رقمی باشد 0 ابتدای عدد قرار میدهد فرمت 12 ساعته

h // ساعت با تک رقم فرمت 12 ساعته 

HH // ساعت با 2 رقم فرمت 24 ساعته 

H // ساعت با تک رقم فرمت 24 ساعته

nn // نمایشه دقیقه به صورت دو رقمی

n // نمایشه دقیقه به صورت تک رقمی

ss // نمایش ثانیه دو رقمی

s  // نمایش ثانیه تک رقمی

SSS // نمایش میلی ثانیه

S // نمایش میلی ثانیه

uuu // نمایش میکرو ثانیه

u // نمایش میکرو ثانیه

am // نمایش وقت به صورت کوتاه 

AM // نمایش وقت به صورت کامل


## گزارش اشکال

در صورت وجود هر گونه مشکل از طریق ایمیل زیر با ما در میان بگذارید[j.zobeidi89@gmail.com][tracker].

[tracker]: mailto:j.zobeidi89@gmail.com
